@@ -5,7 +5,9 @@ use strict;
 use warnings;
 use 5.008001;
 
-our $VERSION = '0.006_020';
+our $VERSION = '0.006_021';
+
+bootstrap Devel::Declare;
 $VERSION =~ tr/_//d;
 
 use constant DECLARE_NAME => 1;
@@ -13,13 +15,11 @@ use constant DECLARE_PROTO => 2;
 use constant DECLARE_NONE => 4;
 use constant DECLARE_PACKAGE => 8+1; # name implicit
 
-use vars qw(%declarators %declarator_handlers @ISA);
+our (%declarators, %declarator_handlers, @ISA);
 use base qw(DynaLoader);
 use Scalar::Util 'set_prototype';
 use B::Hooks::OP::Check 0.19;
 
-bootstrap Devel::Declare;
-
 @ISA = ();
 
 initialize();
